#
# spec file for package python-octave-kernel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# truncate trailing .0
%define distversion 0.36
Name:           python-octave-kernel
Version:        0.36.0
Release:        1.1
Summary:        A Jupyter kernel for Octave
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Calysto/octave_kernel
Source:         https://files.pythonhosted.org/packages/source/o/octave_kernel/octave_kernel-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatchling >= 1.5}
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module jupyter-client >= 4.3.0}
BuildRequires:  %{python_module jupyter_kernel_test}
BuildRequires:  %{python_module jupyter_packaging}
BuildRequires:  %{python_module metakernel >= 0.24.0}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  octave
BuildRequires:  python-rpm-macros
BuildRequires:  xvfb-run
Requires:       jupyter-octave-kernel = %{version}
Requires:       octave
Requires:       python-ipykernel
Requires:       python-jupyter-client >= 4.3.0
Requires:       python-metakernel >= 0.24.0
Provides:       python-jupyter_octave_kernel = %{version}-%{release}
Obsoletes:      python-jupyter_octave_kernel < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
A kernel to allow Octave to be used in Jupyter.

This package provides the python interface.

%package     -n jupyter-octave-kernel
Summary:        Interactive plotting package for the Jupyter notebook
Group:          Development/Languages/Python
Requires:       jupyter-notebook
Requires:       python3dist(octave-kernel) = %{distversion}
Suggests:       python3-octave-kernel = %{version}
Conflicts:      python3-jupyter_octave_kernel < 0.29.0
Provides:       jupyter-octave_kernel = %{version}-%{release}
Obsoletes:      jupyter-octave_kernel < %{version}-%{release}

%description -n jupyter-octave-kernel
A kernel to allow Octave to be used in Jupyter.

This package provides the jupyter notebook extension.

%prep
%setup -q -n octave_kernel-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%fdupes %{buildroot}%{_jupyter_prefix}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export JUPYTER_PATH=%{buildroot}%{_jupyter_prefix}
%{python_expand #
xvfb-run $python -m octave_kernel.check
xvfb-run $python -m unittest -v test_octave_kernel.py
}

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/octave_kernel/
%{python_sitelib}/octave_kernel-%{version}*-info

%files -n jupyter-octave-kernel
%license LICENSE.txt
%{_jupyter_kernel_dir}/octave/

%changelog
* Sun Sep 15 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.36.0
  [#]# Enhancements made
  * Prefer octave-cli if available #236 (@blink1073)
  [#]# Maintenance and upkeep improvements
  * Switch to hatch custom build #238 (@blink1073)
  * Update Release Scripts #237 (@blink1073)
  [#]# Other merged PRs
  * Clarify use environment variable wording #229 (@goyalyashpal)
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (via
  ipykernel)
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.35.1
  * Include test and example notebook in sdist #228 (@blink1073)
- Move to PEP517 hatchling build
* Wed Aug  3 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.34.2
  * Fix error: '_make_figures' undefined near line 1, column 1 #212
* Sat Mar 26 2022 Ben Greiner <code@bnavigator.de>
- Update packaging: install the kernel
- Re-enable tests
* Sun Feb 27 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.34.1:
  * Bugs fixed
    + Improve handling of default inline toolkit #209 (@blink1073)
- changes from version 0.34.0:
  * Enhancements made
    + Use octave executable and qt backend by default #204
    (@blink1073)
  * Maintenance and upkeep improvements
    + Fail if kernel test fails #203 (@blink1073)
    + Use published jupyter_kernel_test #202 (@blink1073)
- changes from version 0.33.1:
  * Maintenance and upkeep improvements
    + Prep for jupyter releaser usage #200 (@blink1073)
    + Upgrade to jupyter packaging and github actions #199
    (@blink1073)
* Tue Oct  5 2021 Ben Greiner <code@bnavigator.de>
- Disable tests: jupyter_kernel_test is broken and did not see any
  maintenance recently.
  * gh#Calysto/octave_kernel#198
  * gh#jupyter/jupyter_kernel_test#55
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.32.0:
  * Fixes for octave5
  * Fixes for new jupyterlab
- Remove fix_octave5.patch
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- jupyter_client renamed to jupyter-client
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Switch from wheel to sdist.
- Add fix_octave5.patch
  Fix tests to work with octave 5
  From: gh#Calysto/octave_kernel#160
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.31.0
  * Use new line_handler
* Thu May 30 2019 Todd R <toddrme2178@gmail.com>
- Fix conflicts.
* Wed May 29 2019 Todd R <toddrme2178@gmail.com>
- Rename to match upstream name change.
- Update to 0.30.3
  * Update configurability handling
  * Allow inline backend to be specified using plot magic
  * Don't give a stack trace on exit
  * clean up plot handling and add config
  * Add support for default plot backend
  * use improved interrupt handling in metakernel
  * clean up executable handling logic
  * Better default setup for engine
  * Adds conda install texinfo for the inline documentation text
  * use jupyter rather than ipython
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match jupyter package naming guidelines.
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to version 0.28.4
  * Include license file in wheels
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.28.3
  * Bugfix release
- Switch to using wheels for more reliable installation
* Wed Apr  4 2018 sebix+novell.com@sebix.at
- Package needed kernel.json file.
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- Use %%license macro for license.
- update to version 0.28.0:
  * Automatically install the kernel when installing the python package. #104
- do not use removed option --display-name anymore for jupyter kernel installation
* Wed Sep 20 2017 toddrme2178@gmail.com
- Update to version 0.27.0
- Only install kernel for python3
* Wed Jul 12 2017 toddrme2178@gmail.com
- Initial version
